==> XML-NewsML_G2-v0.0_2.tar.gz: XML-NewsML_G2-v0.0_2/lib/XML/NewsML_G2/Organisation.pm <==
package XML::NewsML_G2::Organisation;

# $Id: Organisation.pm 46519 2013-05-31 15:38:08Z apatecgortan $

use Moose;
use namespace::autoclean;


has 'name', isa => 'Str', is => 'ro', required => 1;
has 'qcode', isa => 'Str', is => 'ro', required => 1;
has 'isins', isa => 'ArrayRef[Str]', is => 'rw', default => sub { [] },
  traits => ['Array'], handles => {add_isin => 'push'};
has 'websites', isa => 'ArrayRef[Str]', is => 'rw', default => sub { [] },
  traits => ['Array'], handles => {add_website => 'push', has_websites => 'count'};
has 'indices', isa => 'ArrayRef[Str]', is => 'rw', default => sub { [] },
  traits => ['Array'], handles => {add_index => 'push'};
has 'stock_exchanges', isa => 'ArrayRef[Str]', is => 'rw', default => sub { [] },
  traits => ['Array'], handles => {add_stock_exchange => 'push'};

__PACKAGE__->meta->make_immutable;

1;
__END__

=head1 NAME

XML::NewsML_G2::Oranisation - a company or organisation

=head1 SYNOPSIS

    my $org = XML::NewsML_G2::Organisation->new
        (name => 'Google Inc.', qcode => 'gogl', websites => ["http://google.com"]);

=head1 ATTRIBUTES

=over 4

=item name

=item qcode

=item isins

List of international securities identification numbers.

=item websites

List of the websites

=item indices

List of stock indexes covering this organisation

=item stock_exchanges

List of stock exchanges where this organisation is listed

=back

=head2 METHODS

=over 4

=item add_isin

=item add_website

=item add_index

=item add_stock_exchange

=back

=head1 AUTHOR

Philipp Gortan  C<< <philipp.gortan@apa.at> >>

=head1 LICENCE AND COPYRIGHT

Copyright (c) 2013, APA-IT. All rights reserved.

See L<XML::NewsML_G2> for the license.

==> XML-NewsML_G2-v0.2.1.tar.gz: XML-NewsML_G2-v0.2.1/lib/XML/NewsML_G2/Organisation.pm <==
package XML::NewsML_G2::Organisation;

# $Id: Organisation.pm 55790 2014-08-26 18:30:30Z apatecgortan $

use Moose;
use namespace::autoclean;

with 'XML::NewsML_G2::Role::HasQCode';

has 'isins', isa => 'ArrayRef[Str]', is => 'rw', default => sub { [] },
  traits => ['Array'], handles => {add_isin => 'push'};
has 'websites', isa => 'ArrayRef[Str]', is => 'rw', default => sub { [] },
  traits => ['Array'], handles => {add_website => 'push', has_websites => 'count'};
has 'indices', isa => 'ArrayRef[Str]', is => 'rw', default => sub { [] },
  traits => ['Array'], handles => {add_index => 'push'};
has 'stock_exchanges', isa => 'ArrayRef[Str]', is => 'rw', default => sub { [] },
  traits => ['Array'], handles => {add_stock_exchange => 'push'};

__PACKAGE__->meta->make_immutable;

1;
__END__

=head1 NAME

XML::NewsML_G2::Oranisation - a company or organisation

=head1 SYNOPSIS

    my $org = XML::NewsML_G2::Organisation->new
        (name => 'Google Inc.', qcode => 'gogl', websites => ["http://google.com"]);

=head1 ATTRIBUTES

=over 4

=item isins

List of international securities identification numbers.

=item websites

List of the websites

=item indices

List of stock indexes covering this organisation

=item stock_exchanges

List of stock exchanges where this organisation is listed

=back

=head2 METHODS

=over 4

=item add_isin

=item add_website

=item add_index

=item add_stock_exchange

=back

=head1 AUTHOR

Philipp Gortan  C<< <philipp.gortan@apa.at> >>

=head1 LICENCE AND COPYRIGHT

Copyright (c) 2013-2014, APA-IT. All rights reserved.

See L<XML::NewsML_G2> for the license.
